<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns="http://www.w3.org/1999/xhtml"
    xpath-default-namespace="http://www.w3.org/1999/xhtml"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:whc="http://www.oxygenxml.com/webhelp/components"
    xmlns:toc="http://www.oxygenxml.com/ns/webhelp/toc"
    xmlns:math="http://www.w3.org/2005/xpath-functions/math"
    xmlns:fn="http://www.w3.org/2005/xpath-functions" exclude-result-prefixes="fn math xs whc toc"
    version="3.0">


    <!-- to change the home page for WebHelp output, set @outputclass="landing_page" on the desired topic:

        <map>
            <topicref href="olh/my_landing_page.dita" outputclass="landing_page"/>
            ...

    -->



    <!-- this variable contains the path to the landing page HTML (or nothing, if no landing page exists) -->
    <xsl:variable name="landing-page-href" select="($toc//*[contains-token(@outputclass, 'landing_page')])[1]/@href" as="xs:string?"/>


    <!-- change home page links in
         * header map title (whc:webhelp_publication_title)
         * header breadcrumbs (whc:webhelp_breadcrumb)
    -->
    <xsl:template match="(whc:webhelp_publication_title|whc:webhelp_breadcrumb)[$landing-page-href]" mode="copy_template">
        <xsl:variable name="results">
            <xsl:next-match/>  <!-- get (almost) final HTML -->
        </xsl:variable>
        <xsl:apply-templates select="$results" mode="change-home-page"/>  <!-- change references to default home page -->
    </xsl:template>

    <!-- this mode changes <a href="index.html"> links to point to our landing page instead -->
    <xsl:mode name="change-home-page" on-no-match="shallow-copy"/>

    <!-- change header map title link -->
    <xsl:template match="div[contains-token(@class, 'wh_publication_title')]/a/@href" mode="change-home-page">
        <xsl:attribute name="href" select="$PATH2PROJ || $landing-page-href"/>
    </xsl:template>

    <!-- change header "Home" link -->
    <xsl:template match="div[contains-token(@class, 'wh_breadcrumb')]/ol/li[1]/span[contains-token(@class, 'home')]/a/@href" mode="change-home-page">
        <xsl:attribute name="href" select="$PATH2PROJ || $landing-page-href"/>
    </xsl:template>



    <!-- completely replace the main page with a redirect to the landing page -->
    <xsl:template match="html[body[contains-token(@class, 'wh_main_page')]][$landing-page-href]" mode="copy_template">
      <xsl:copy>
        <xsl:sequence select="@*"/>
        <head>
          <meta http-equiv="refresh" content="0; url='{$landing-page-href}'" />
        </head>
        <body>
          <p>Please follow <a href="{$landing-page-href}">this link</a>.</p>
        </body>
      </xsl:copy>
    </xsl:template>

</xsl:stylesheet>
